#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Fenrir TTY screen reader
# By Chrys, Storm Dragon, and contributers.

from fenrirscreenreader.core import debug
import os
import importlib
import _thread
import pyperclip

class command():
    def __init__(self):
        pass
    def initialize(self, environment, scriptPath=''):
        self.env = environment
        self.scriptPath = scriptPath
    def shutdown(self):
        pass
    def getDescription(self):
        return _('Export current fenrir clipboard to X or GUI clipboard')
    def run(self):                       
       _thread.start_new_thread(self._threadRun , ())
    def _threadRun(self):
        try:
            # Check if clipboard is empty
            if self.env['runtime']['memoryManager'].isIndexListEmpty('clipboardHistory'):
                self.env['runtime']['outputManager'].presentText(_('clipboard empty'), interrupt=True)
                return
            
            # Get current clipboard content
            clipboard = self.env['runtime']['memoryManager'].getIndexListElement('clipboardHistory')
            
            # Remember original display environment variable if it exists
            originalDisplay = os.environ.get('DISPLAY', '')
            success = False
            
            # Try different display options
            for i in range(10):
                display = f":{i}"
                try:
                    # Set display environment variable
                    os.environ['DISPLAY'] = display
                    # Attempt to set clipboard content
                    importlib.reload(pyperclip) # Weird workaround for some distros
                    pyperclip.copy(clipboard)
                    # If we get here without exception, we found a working display
                    success = True
                    break
                except Exception:
                    # Failed for this display, try next one
                    continue
            
            # Restore original display setting
            if originalDisplay:
                os.environ['DISPLAY'] = originalDisplay
            else:
                os.environ.pop('DISPLAY', None)
            
            # Notify the user of the result
            if success:
                self.env['runtime']['outputManager'].presentText(_('exported to the X session.'), interrupt=True)
            else:
                self.env['runtime']['outputManager'].presentText(_('failed to export to X clipboard. No available display found.'), interrupt=True)
                
        except Exception as e:
            self.env['runtime']['outputManager'].presentText(str(e), soundIcon='', interrupt=False)
        
    def setCallback(self, callback):
        pass
